@@ -10,7 +10,6 @@
 
 
 import time
-import uvicorn
 
 from datetime import datetime
 from typing import Optional
@@ -28,8 +27,14 @@ app = FastAPI()
 @app.post('/')
 def read_root(kwargs:dict):
     print(kwargs)
-    return kwargs.get("CHALLENGE")
+    return kwargs
 
+@app.post('/')
+def read_root(kwargs:dict):
+    print(kwargs)
+    return kwargs
 
 if __name__ == '__main__':
-    uvicorn.run(app, host='10.234.212.17')
+    import uvicorn
+
+    uvicorn.run(app)
